Гипотезы и план действий

1. Попробовать извлечь текстовые признаки из URL (TF-IDF, CountVectorizer)
2. Парсинг странички для извлечения доп инеформации с нее
3. Скачивание картинки + ее классификация с помощью модельки
4. Использование Open Source LLM модельки для классификации по url, а может можно и про API ходить и даже платно, если такое разрешено
5. Построение Мета модельки для классификации

Метрики для оценки:

1. Accuracy
2. F1-score
3. Confusion Matrix
